import axios from './axios'
import { Toast, Dialog } from 'vant'
import router from '../router/index'
import selfApi from '@/api/apiList'

const instance = axios()

export default {
    get (url, params, headers, toast = true) {
        const options = {}

        options.headers = {
            token: window.localStorage.getItem('token')
            // token: 'sys'
            // type: 1
        }

        if (params) {
            options.params = params
        }

        if (headers) {
            options.headers = {
                ...options.headers,
                ...headers
            }
        }
        Toast.allowMultiple()
        let tipsToast = ''
        if (toast) {
            tipsToast = Toast.loading({
                message: '正在请求...',
                duration: 0,
                forbidClick: true,
                loadingType: 'spinner'
            })
        }
        return new Promise((resolve, reject) => {
            instance.get(url, options).then(res => {
                const {
                    data,
                    meta
                } = res
                // console.log(code, typeof code, '11111111111111')
                toast && tipsToast.clear()
                if (meta.code === 200) {
                    resolve(data)
                } else if (meta.code === -300) {
                    window.localStorage.clear()
                    Toast('身份失效，请重新登录')
                    window.document.location = selfApi.WINDOWHREF_LOGIN // url-
                } else {
                    reject(res)
                    Toast(meta.message)
                }
            }).catch(err => {
                toast && tipsToast.clear()
                reject(err)
            })
        })
    },

    post (url, data, headers, params, toast = true) {
        const options = {}

        options.headers = {
            token: window.localStorage.getItem('token')
            // token: 'sys'
            // type: 1
        }

        if (params) {
            options.params = params
        }
        if (headers) {
            options.headers = {
                ...options.headers,
                ...headers
            }
        }
        Toast.allowMultiple()
        let tipsToast = ''
        if (toast) {
            tipsToast = Toast.loading({
                message: '正在请求...',
                duration: 0,
                forbidClick: true,
                loadingType: 'spinner'
            })
        }
        return new Promise((resolve, reject) => {
            instance.post(url, data, options).then(res => {
                const {
                    data,
                    meta
                } = res
                toast && tipsToast.clear()
                if (meta.code === 200) {
                    resolve(data)
                } else if (meta.code === -300) {
                    window.localStorage.clear()
                    Toast('身份失效，请重新登录')
                    window.document.location = selfApi.WINDOWHREF_LOGIN // url-
                } else {
                    reject(res)
                    Toast(meta.message)
                }
            }).catch(err => {
                toast && tipsToast.clear()
                reject(err)
            })
        })
    },

    put (url, params, headers) {
        const options = {}

        if (headers) {
            options.headers = {
                ...options.headers,
                ...headers
            }
        }
        return new Promise((resolve, reject) => {
            instance.put(url, params, options).then(res => {
                const {
                    code,
                    data,
                    message
                } = res
                if (code === 200) {
                    resolve(data)
                } else if (code !== 400) {
                    reject(res)
                    Toast(message)
                }
            }).catch(err => {
                reject(err)
            })
        })
    },

    delete (url, params, headers) {
        const options = {}

        if (params) {
            options.params = params
        }
        if (headers) {
            options.headers = {
                ...options.headers,
                ...headers
            }
        }
        return instance.delete(url, options)
    }
}
